import { Component, Input } from '@angular/core';
import { WizardState } from '../navigation/wizard-state.model';
/**
 * The `wizard-navigation-bar` component contains the navigation bar inside a [[WizardComponent]].
 * To correctly display the navigation bar, it's required to set the right css classes for the navigation bar,
 * otherwise it will look like a normal `ul` component.
 *
 * ### Syntax
 *
 * ```html
 * <wizard-navigation-bar></wizard-navigation-bar>
 * ```
 *
 * @author Marc Arndt
 */
var WizardNavigationBarComponent = /** @class */ (function () {
    /**
     * Constructor
     *
     * @param wizardState The state the wizard currently resides in
     */
    function WizardNavigationBarComponent(wizardState) {
        this.wizardState = wizardState;
        /**
         * The direction in which the wizard steps should be shown in the navigation bar.
         * This value can be either `left-to-right` or `right-to-left`
         */
        this.direction = 'left-to-right';
    }
    Object.defineProperty(WizardNavigationBarComponent.prototype, "navigationMode", {
        /**
         * The navigation mode
         *
         * @returns {NavigationMode}
         */
        get: function () {
            return this.wizardState.navigationMode;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WizardNavigationBarComponent.prototype, "wizardSteps", {
        /**
         * Returns all [[WizardStep]]s contained in the wizard
         *
         * @returns {Array<WizardStep>} An array containing all [[WizardStep]]s
         */
        get: function () {
            switch (this.direction) {
                case 'right-to-left':
                    return this.wizardState.wizardSteps.reverse();
                case 'left-to-right':
                default:
                    return this.wizardState.wizardSteps;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WizardNavigationBarComponent.prototype, "numberOfWizardSteps", {
        /**
         * Returns the number of wizard steps, that need to be displaced in the navigation bar
         *
         * @returns {number} The number of wizard steps to be displayed
         */
        get: function () {
            return this.wizardState.wizardSteps.length;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Checks, whether a [[WizardStep]] can be marked as `current` in the navigation bar
     *
     * @param {WizardStep} wizardStep The wizard step to be checked
     * @returns {boolean} True if the step can be marked as current
     */
    WizardNavigationBarComponent.prototype.isCurrent = function (wizardStep) {
        return wizardStep.selected && !wizardStep.completed && !this.wizardState.completed;
    };
    /**
     * Checks, whether a [[WizardStep]] can be marked as `done` in the navigation bar
     *
     * @param {WizardStep} wizardStep The wizard step to be checked
     * @returns {boolean} True if the step can be marked as done
     */
    WizardNavigationBarComponent.prototype.isDone = function (wizardStep) {
        return (wizardStep.completed && !wizardStep.selected) || this.wizardState.completed;
    };
    /**
     * Checks, whether a [[WizardStep]] can be marked as `default` in the navigation bar
     *
     * @param {WizardStep} wizardStep The wizard step to be checked
     * @returns {boolean} True if the step can be marked as default
     */
    WizardNavigationBarComponent.prototype.isDefault = function (wizardStep) {
        return !wizardStep.optional && !wizardStep.completed && !wizardStep.selected && !this.wizardState.completed;
    };
    /**
     * Checks, whether a [[WizardStep]] can be marked as `editing` in the navigation bar
     *
     * @param {WizardStep} wizardStep The wizard step to be checked
     * @returns {boolean} True if the step can be marked as editing
     */
    WizardNavigationBarComponent.prototype.isEditing = function (wizardStep) {
        return wizardStep.selected && wizardStep.completed && !this.wizardState.completed;
    };
    /**
     * Checks, whether a [[WizardStep]] can be marked as `optional` in the navigation bar
     *
     * @param {WizardStep} wizardStep The wizard step to be checked
     * @returns {boolean} True if the step can be marked as optional
     */
    WizardNavigationBarComponent.prototype.isOptional = function (wizardStep) {
        return wizardStep.optional && !wizardStep.completed && !wizardStep.selected && !this.wizardState.completed;
    };
    /**
     * Checks, whether a [[WizardStep]] can be marked as `navigable` in the navigation bar.
     * A wizard step can be navigated to if:
     * - the step is currently not selected
     * - the navigation bar isn't disabled
     * - the navigation mode allows navigation to the step
     *
     * @param {WizardStep} wizardStep The wizard step to be checked
     * @returns {boolean} True if the step can be marked as navigable
     */
    WizardNavigationBarComponent.prototype.isNavigable = function (wizardStep) {
        return !wizardStep.selected && !this.wizardState.disableNavigationBar &&
            this.navigationMode.isNavigable(this.wizardState.getIndexOfStep(wizardStep));
    };
    WizardNavigationBarComponent.decorators = [
        { type: Component, args: [{
                    selector: 'wizard-navigation-bar',
                    template: "\n    <ul class=\"steps-indicator steps-{{numberOfWizardSteps}}\">\n      <li *ngFor=\"let step of wizardSteps\"\n          [attr.step-symbol]=\"step.navigationSymbol\"\n          [ngStyle]=\"{\n            'font-family': step.navigationSymbolFontFamily\n          }\"\n          [ngClass]=\"{\n            default: isDefault(step),\n            current: isCurrent(step),\n            done: isDone(step),\n            editing: isEditing(step),\n            optional: isOptional(step),\n            navigable: isNavigable(step)\n      }\">\n        <div>\n          <a [goToStep]=\"step\">\n            <ng-container *ngIf=\"step.stepTitleTemplate\" [ngTemplateOutlet]=\"step.stepTitleTemplate.templateRef\"></ng-container>\n            <ng-container *ngIf=\"!step.stepTitleTemplate\">{{step.stepTitle}}</ng-container>\n          </a>\n        </div>\n      </li>\n    </ul>\n  ",
                    styles: ["\n    /*\n     color definitions\n     */\n    /*\n     dot definitions\n     */\n    /*\n     extra distance between the bottom of the dots and the baseline texts\n     */\n    :host.horizontal.small ul.steps-indicator {\n      padding: 24px 0 10px 0;\n    }\n    :host.horizontal.small ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      height: 1px;\n      width: calc(100% - 14px);\n      top: -7px;\n      left: calc(50% + 7px);\n    }\n    :host.horizontal.small ul.steps-indicator li:after {\n      position: absolute;\n      top: -14px;\n      left: calc(50% - 7px);\n      width: 14px;\n      height: 14px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 14px;\n      transition: 0.25s;\n      border-radius: 100%;\n      background-color: #E6E6E6;\n    }\n    :host.horizontal.small ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.horizontal.small ul.steps-indicator li.current:after {\n      background-color: #808080;\n    }\n    :host.horizontal.small ul.steps-indicator li.done:after {\n      background-color: #339933;\n    }\n    :host.horizontal.small ul.steps-indicator li.optional:after {\n      background-color: #38ef38;\n    }\n    :host.horizontal.small ul.steps-indicator li.editing:after {\n      background-color: #FF0000;\n    }\n    :host.horizontal.large-filled ul.steps-indicator {\n      padding: 60px 0 10px 0;\n    }\n    :host.horizontal.large-filled ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      height: 1px;\n      width: calc(100% - 50px);\n      top: -25px;\n      left: calc(50% + 25px);\n    }\n    :host.horizontal.large-filled ul.steps-indicator li:after {\n      position: absolute;\n      top: -50px;\n      left: calc(50% - 25px);\n      width: 50px;\n      height: 50px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 50px;\n      transition: 0.25s;\n      border-radius: 100%;\n      background-color: #E6E6E6;\n    }\n    :host.horizontal.large-filled ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.horizontal.large-filled ul.steps-indicator li.current:after {\n      background-color: #808080;\n    }\n    :host.horizontal.large-filled ul.steps-indicator li.done:after {\n      background-color: #339933;\n    }\n    :host.horizontal.large-filled ul.steps-indicator li.optional:after {\n      background-color: #38ef38;\n    }\n    :host.horizontal.large-filled ul.steps-indicator li.editing:after {\n      background-color: #FF0000;\n    }\n    :host.horizontal.large-empty ul.steps-indicator {\n      padding: 60px 0 10px 0;\n    }\n    :host.horizontal.large-empty ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      height: 1px;\n      width: calc(100% - 50px);\n      top: -25px;\n      left: calc(50% + 25px);\n    }\n    :host.horizontal.large-empty ul.steps-indicator li:after {\n      position: absolute;\n      top: -50px;\n      left: calc(50% - 25px);\n      width: 50px;\n      height: 50px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 46px;\n      transition: 0.25s;\n      border-radius: 100%;\n      border-width: 2px;\n      border-style: solid;\n      border-color: #E6E6E6;\n    }\n    :host.horizontal.large-empty ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.horizontal.large-empty ul.steps-indicator li.current:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #808080;\n    }\n    :host.horizontal.large-empty ul.steps-indicator li.done:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #339933;\n    }\n    :host.horizontal.large-empty ul.steps-indicator li.optional:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #38ef38;\n    }\n    :host.horizontal.large-empty ul.steps-indicator li.editing:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #FF0000;\n    }\n    :host.horizontal.large-filled-symbols ul.steps-indicator {\n      padding: 60px 0 10px 0;\n    }\n    :host.horizontal.large-filled-symbols ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      height: 1px;\n      width: calc(100% - 50px);\n      top: -25px;\n      left: calc(50% + 25px);\n    }\n    :host.horizontal.large-filled-symbols ul.steps-indicator li:after {\n      position: absolute;\n      top: -50px;\n      left: calc(50% - 25px);\n      width: 50px;\n      height: 50px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 50px;\n      transition: 0.25s;\n      border-radius: 100%;\n      background-color: #E6E6E6;\n      color: black;\n      content: attr(step-symbol);\n    }\n    :host.horizontal.large-filled-symbols ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.horizontal.large-filled-symbols ul.steps-indicator li.current:after {\n      background-color: #808080;\n      color: black;\n    }\n    :host.horizontal.large-filled-symbols ul.steps-indicator li.done:after {\n      background-color: #339933;\n      color: black;\n    }\n    :host.horizontal.large-filled-symbols ul.steps-indicator li.optional:after {\n      background-color: #38ef38;\n      color: black;\n    }\n    :host.horizontal.large-filled-symbols ul.steps-indicator li.editing:after {\n      background-color: #FF0000;\n      color: black;\n    }\n    :host.horizontal.large-empty-symbols ul.steps-indicator {\n      padding: 60px 0 10px 0;\n    }\n    :host.horizontal.large-empty-symbols ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      height: 1px;\n      width: calc(100% - 50px);\n      top: -25px;\n      left: calc(50% + 25px);\n    }\n    :host.horizontal.large-empty-symbols ul.steps-indicator li:after {\n      position: absolute;\n      top: -50px;\n      left: calc(50% - 25px);\n      width: 50px;\n      height: 50px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 46px;\n      transition: 0.25s;\n      border-radius: 100%;\n      border-width: 2px;\n      border-style: solid;\n      border-color: #E6E6E6;\n      color: #E6E6E6;\n      content: attr(step-symbol);\n    }\n    :host.horizontal.large-empty-symbols ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.horizontal.large-empty-symbols ul.steps-indicator li.current:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #808080;\n      color: #808080;\n    }\n    :host.horizontal.large-empty-symbols ul.steps-indicator li.done:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #339933;\n      color: #339933;\n    }\n    :host.horizontal.large-empty-symbols ul.steps-indicator li.optional:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #38ef38;\n      color: #38ef38;\n    }\n    :host.horizontal.large-empty-symbols ul.steps-indicator li.editing:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #FF0000;\n      color: #FF0000;\n    }\n    :host.horizontal ul.steps-indicator {\n      display: flex;\n      flex-direction: row;\n      justify-content: center;\n      right: 0;\n      bottom: 0;\n      left: 0;\n      margin: 0;\n      width: 100%;\n      list-style: none;\n      /* --- http://www.paulirish.com/2012/box-sizing-border-box-ftw/ ---- */\n    }\n    :host.horizontal ul.steps-indicator.steps-2:before {\n      left: 25%;\n      right: 25%;\n    }\n    :host.horizontal ul.steps-indicator.steps-2 li {\n      width: 50%;\n    }\n    :host.horizontal ul.steps-indicator.steps-3:before {\n      left: 16.66666667%;\n      right: 16.66666667%;\n    }\n    :host.horizontal ul.steps-indicator.steps-3 li {\n      width: 33.33333333%;\n    }\n    :host.horizontal ul.steps-indicator.steps-4:before {\n      left: 12.5%;\n      right: 12.5%;\n    }\n    :host.horizontal ul.steps-indicator.steps-4 li {\n      width: 25%;\n    }\n    :host.horizontal ul.steps-indicator.steps-5:before {\n      left: 10%;\n      right: 10%;\n    }\n    :host.horizontal ul.steps-indicator.steps-5 li {\n      width: 20%;\n    }\n    :host.horizontal ul.steps-indicator.steps-6:before {\n      left: 8.33333333%;\n      right: 8.33333333%;\n    }\n    :host.horizontal ul.steps-indicator.steps-6 li {\n      width: 16.66666667%;\n    }\n    :host.horizontal ul.steps-indicator.steps-7:before {\n      left: 7.14285714%;\n      right: 7.14285714%;\n    }\n    :host.horizontal ul.steps-indicator.steps-7 li {\n      width: 14.28571429%;\n    }\n    :host.horizontal ul.steps-indicator.steps-8:before {\n      left: 6.25%;\n      right: 6.25%;\n    }\n    :host.horizontal ul.steps-indicator.steps-8 li {\n      width: 12.5%;\n    }\n    :host.horizontal ul.steps-indicator.steps-9:before {\n      left: 5.55555556%;\n      right: 5.55555556%;\n    }\n    :host.horizontal ul.steps-indicator.steps-9 li {\n      width: 11.11111111%;\n    }\n    :host.horizontal ul.steps-indicator.steps-10:before {\n      left: 5%;\n      right: 5%;\n    }\n    :host.horizontal ul.steps-indicator.steps-10 li {\n      width: 10%;\n    }\n    :host.horizontal ul.steps-indicator * {\n      -webkit-box-sizing: border-box;\n      -moz-box-sizing: border-box;\n      box-sizing: border-box;\n    }\n    :host.horizontal ul.steps-indicator li {\n      position: relative;\n      margin: 0;\n      padding: 10px 0 0 0;\n      pointer-events: none;\n    }\n    :host.horizontal ul.steps-indicator li div {\n      display: flex;\n      flex-direction: column;\n      align-items: center;\n    }\n    :host.horizontal ul.steps-indicator li div a {\n      color: #808080;\n      line-height: 14px;\n      font-size: 14px;\n      text-decoration: none;\n      text-transform: uppercase;\n      text-align: center;\n      font-weight: bold;\n      transition: 0.25s;\n      cursor: pointer;\n    }\n    :host.horizontal ul.steps-indicator li div a:hover {\n      color: #4d4d4d;\n    }\n    :host.horizontal ul.steps-indicator li.navigable {\n      pointer-events: auto;\n    }\n    /*\n     color definitions\n     */\n    /*\n     dot definitions\n     */\n    /*\n     extra distance between the bottom of the dots and the baseline texts\n     */\n    :host.vertical {\n      max-width: 280px;\n      width: 20%;\n      height: 100%;\n      position: sticky;\n      top: 0;\n    }\n    :host.vertical.small ul.steps-indicator {\n      padding: 5px 5px 5px 19px;\n    }\n    :host.vertical.small ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      left: -7px;\n      top: 14px;\n      height: calc(100% - 14px);\n      width: 1px;\n    }\n    :host.vertical.small ul.steps-indicator li:after {\n      position: absolute;\n      top: 0;\n      left: -14px;\n      width: 14px;\n      height: 14px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 14px;\n      transition: 0.25s;\n      border-radius: 100%;\n      background-color: #E6E6E6;\n    }\n    :host.vertical.small ul.steps-indicator li div {\n      min-height: 14px;\n    }\n    :host.vertical.small ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.vertical.small ul.steps-indicator li.current:after {\n      background-color: #808080;\n    }\n    :host.vertical.small ul.steps-indicator li.done:after {\n      background-color: #339933;\n    }\n    :host.vertical.small ul.steps-indicator li.optional:after {\n      background-color: #38ef38;\n    }\n    :host.vertical.small ul.steps-indicator li.editing:after {\n      background-color: #FF0000;\n    }\n    :host.vertical.large-filled ul.steps-indicator {\n      padding: 5px 5px 5px 55px;\n    }\n    :host.vertical.large-filled ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      left: -25px;\n      top: 50px;\n      height: calc(100% - 50px);\n      width: 1px;\n    }\n    :host.vertical.large-filled ul.steps-indicator li:after {\n      position: absolute;\n      top: 0;\n      left: -50px;\n      width: 50px;\n      height: 50px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 50px;\n      transition: 0.25s;\n      border-radius: 100%;\n      background-color: #E6E6E6;\n    }\n    :host.vertical.large-filled ul.steps-indicator li div {\n      min-height: 50px;\n    }\n    :host.vertical.large-filled ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.vertical.large-filled ul.steps-indicator li.current:after {\n      background-color: #808080;\n    }\n    :host.vertical.large-filled ul.steps-indicator li.done:after {\n      background-color: #339933;\n    }\n    :host.vertical.large-filled ul.steps-indicator li.optional:after {\n      background-color: #38ef38;\n    }\n    :host.vertical.large-filled ul.steps-indicator li.editing:after {\n      background-color: #FF0000;\n    }\n    :host.vertical.large-empty ul.steps-indicator {\n      padding: 5px 5px 5px 55px;\n    }\n    :host.vertical.large-empty ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      left: -25px;\n      top: 50px;\n      height: calc(100% - 50px);\n      width: 1px;\n    }\n    :host.vertical.large-empty ul.steps-indicator li:after {\n      position: absolute;\n      top: 0;\n      left: -50px;\n      width: 50px;\n      height: 50px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 46px;\n      transition: 0.25s;\n      border-radius: 100%;\n      border-width: 2px;\n      border-style: solid;\n      border-color: #E6E6E6;\n    }\n    :host.vertical.large-empty ul.steps-indicator li div {\n      min-height: 54px;\n    }\n    :host.vertical.large-empty ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.vertical.large-empty ul.steps-indicator li.current:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #808080;\n    }\n    :host.vertical.large-empty ul.steps-indicator li.done:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #339933;\n    }\n    :host.vertical.large-empty ul.steps-indicator li.optional:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #38ef38;\n    }\n    :host.vertical.large-empty ul.steps-indicator li.editing:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #FF0000;\n    }\n    :host.vertical.large-filled-symbols ul.steps-indicator {\n      padding: 5px 5px 5px 55px;\n    }\n    :host.vertical.large-filled-symbols ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      left: -25px;\n      top: 50px;\n      height: calc(100% - 50px);\n      width: 1px;\n    }\n    :host.vertical.large-filled-symbols ul.steps-indicator li:after {\n      position: absolute;\n      top: 0;\n      left: -50px;\n      width: 50px;\n      height: 50px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 50px;\n      transition: 0.25s;\n      border-radius: 100%;\n      background-color: #E6E6E6;\n      color: black;\n      content: attr(step-symbol);\n    }\n    :host.vertical.large-filled-symbols ul.steps-indicator li div {\n      min-height: 50px;\n    }\n    :host.vertical.large-filled-symbols ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.vertical.large-filled-symbols ul.steps-indicator li.current:after {\n      background-color: #808080;\n      color: black;\n    }\n    :host.vertical.large-filled-symbols ul.steps-indicator li.done:after {\n      background-color: #339933;\n      color: black;\n    }\n    :host.vertical.large-filled-symbols ul.steps-indicator li.optional:after {\n      background-color: #38ef38;\n      color: black;\n    }\n    :host.vertical.large-filled-symbols ul.steps-indicator li.editing:after {\n      background-color: #FF0000;\n      color: black;\n    }\n    :host.vertical.large-empty-symbols ul.steps-indicator {\n      padding: 5px 5px 5px 55px;\n    }\n    :host.vertical.large-empty-symbols ul.steps-indicator li:not(:last-child):before {\n      background-color: #E6E6E6;\n      content: '';\n      position: absolute;\n      left: -25px;\n      top: 50px;\n      height: calc(100% - 50px);\n      width: 1px;\n    }\n    :host.vertical.large-empty-symbols ul.steps-indicator li:after {\n      position: absolute;\n      top: 0;\n      left: -50px;\n      width: 50px;\n      height: 50px;\n      content: '';\n      text-align: center;\n      vertical-align: middle;\n      line-height: 46px;\n      transition: 0.25s;\n      border-radius: 100%;\n      border-width: 2px;\n      border-style: solid;\n      border-color: #E6E6E6;\n      color: #E6E6E6;\n      content: attr(step-symbol);\n    }\n    :host.vertical.large-empty-symbols ul.steps-indicator li div {\n      min-height: 54px;\n    }\n    :host.vertical.large-empty-symbols ul.steps-indicator li.default a:hover {\n      color: #808080;\n    }\n    :host.vertical.large-empty-symbols ul.steps-indicator li.current:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #808080;\n      color: #808080;\n    }\n    :host.vertical.large-empty-symbols ul.steps-indicator li.done:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #339933;\n      color: #339933;\n    }\n    :host.vertical.large-empty-symbols ul.steps-indicator li.optional:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #38ef38;\n      color: #38ef38;\n    }\n    :host.vertical.large-empty-symbols ul.steps-indicator li.editing:after {\n      border-width: 2px;\n      border-style: solid;\n      border-color: #FF0000;\n      color: #FF0000;\n    }\n    :host.vertical ul.steps-indicator {\n      display: flex;\n      flex-direction: column;\n      justify-content: center;\n      list-style: none;\n      margin: auto;\n      /* --- http://www.paulirish.com/2012/box-sizing-border-box-ftw/ ---- */\n    }\n    :host.vertical ul.steps-indicator * {\n      -webkit-box-sizing: border-box;\n      -moz-box-sizing: border-box;\n      box-sizing: border-box;\n    }\n    :host.vertical ul.steps-indicator li {\n      position: relative;\n      pointer-events: none;\n    }\n    :host.vertical ul.steps-indicator li:not(:last-child) {\n      margin-bottom: 0;\n      padding-bottom: 10px;\n    }\n    :host.vertical ul.steps-indicator li div {\n      display: flex;\n      flex-direction: row;\n      align-items: center;\n    }\n    :host.vertical ul.steps-indicator li div a {\n      color: #808080;\n      margin-left: 15px;\n      line-height: 14px;\n      font-size: 14px;\n      text-decoration: none;\n      text-transform: uppercase;\n      text-align: left;\n      font-weight: bold;\n      transition: 0.25s;\n      cursor: pointer;\n    }\n    :host.vertical ul.steps-indicator li div a:hover {\n      color: #4d4d4d;\n    }\n    :host.vertical ul.steps-indicator li.navigable {\n      pointer-events: auto;\n    }\n  "]
                },] },
    ];
    /** @nocollapse */
    WizardNavigationBarComponent.ctorParameters = function () { return [
        { type: WizardState, },
    ]; };
    WizardNavigationBarComponent.propDecorators = {
        'direction': [{ type: Input },],
    };
    return WizardNavigationBarComponent;
}());
export { WizardNavigationBarComponent };
//# sourceMappingURL=wizard-navigation-bar.component.js.map